@@ -38,6 +38,10 @@ DocumentLinkOptions <- list(
     resolveProvider = FALSE
 )
 
+RenameOptions <- list(
+    prepareProvider = TRUE
+)
+
 ExecuteCommandOptions <- list(
     commands = NULL
 )
@@ -50,7 +54,7 @@ ServerCapabilities <- list(
     # typeDefinitionProvider = FALSE,
     # implementationProvider = FALSE,
     definitionProvider = TRUE,
-    # referencesProvider = FALSE
+    referencesProvider = TRUE,
     documentHighlightProvider = TRUE,
     documentSymbolProvider = TRUE,
     workspaceSymbolProvider = TRUE,
@@ -59,7 +63,7 @@ ServerCapabilities <- list(
     documentFormattingProvider = TRUE,
     documentRangeFormattingProvider = TRUE,
     documentOnTypeFormattingProvider = DocumentOnTypeFormattingOptions,
-    # renameProvider = FALSE,
+    renameProvider = TRUE,
     documentLinkProvider = DocumentLinkOptions,
     colorProvider = TRUE,
     foldingRangeProvider = TRUE
@@ -67,3 +71,14 @@ ServerCapabilities <- list(
     # executeCommandProvider = ExecuteCommandOptions,
     # workspace = list()
 )
+
+update_server_capabilities <- function(server_capabilities, client_capabilities) {
+    # RenameOptions may only be specified if the client states that
+    # it supports prepareSupport in its initial initialize request
+    if (isTRUE(server_capabilities$renameProvider) &&
+        isTRUE(client_capabilities$textDocument$rename$prepareSupport)) {
+        server_capabilities$renameProvider <- RenameOptions
+    }
+
+    server_capabilities
+}
