@@ -154,7 +154,7 @@ Workspace <- R6::R6Class("Workspace",
 
         get_documentation = function(topic, pkgname = NULL, isf = FALSE) {
             if (is.null(pkgname)) {
-                pkgname <- self$guess_namespace(topic, isf = TRUE)
+                pkgname <- self$guess_namespace(topic, isf = isf)
                 if (is.null(pkgname)) {
                     return(NULL)
                 }
@@ -226,7 +226,7 @@ Workspace <- R6::R6Class("Workspace",
 
         load_all = function(langserver) {
             source_dir <- file.path(self$root, "R")
-            files <- list.files(source_dir)
+            files <- list.files(source_dir, pattern = "\\.r$", ignore.case = TRUE)
             for (f in files) {
                 logger$info("load ", f)
                 path <- file.path(source_dir, f)
